@@ -79,13 +79,19 @@ def augments(cls_cpp: Type[Any]):
     This works on pure Python classes too.
 
     THIS DOES NOT work for class methods.
+
+    (Alternative ideas: https://github.com/pybind/pybind11/issues/1074)
     """
+    ATTR_WHITELIST = {'__repr__', '__enter__', '__exit__'}
 
     def class_augment(cls, cls_cpp=cls_cpp):
         for name, member in inspect.getmembers(cls):
-            if hasattr(cls_cpp, name):  # For PyPy: don't replace existing methods
+            # Don't replace existing methods except those in our whitelist
+            if hasattr(cls_cpp, name) and name not in ATTR_WHITELIST:
                 continue
             if inspect.isfunction(member):
+                if member.__qualname__.startswith('object.'):
+                    continue  # To avoid breaking PyPy
                 member.__qualname__ = member.__qualname__.replace(
                     cls.__name__, cls_cpp.__name__
                 )
@@ -93,11 +99,11 @@ def augments(cls_cpp: Type[Any]):
             elif inspect.isdatadescriptor(member):
                 setattr(cls_cpp, name, member)
 
-        def block_init(self):
+        def disable_init(self):
             # Prevent initialization of the support class
             raise NotImplementedError(self.__class__.__name__ + '.__init__')
 
-        cls.__init__ = block_init
+        cls.__init__ = disable_init
         return cls
 
     return class_augment
@@ -550,19 +556,12 @@ class Extend_Pdf:
 
         problems: List[str] = []
 
-        try:
-            self._decode_all_streams_and_discard()
-        except PdfError as e:
-            problems.append(str(e))
+        self._decode_all_streams_and_discard()
 
         discarding_parser = DiscardingParser()
-
         for basic_page in self.pages:
             page = Page(basic_page)
-            try:
-                page.parse_contents(discarding_parser)
-            except PdfError as e:
-                problems.append(str(e))
+            page.parse_contents(discarding_parser)
 
         for warning in self.get_warnings():
             problems.append("WARNING: " + warning)
@@ -929,14 +928,6 @@ class Extend_Pdf:
 
 @augments(_ObjectMapping)
 class Extend_ObjectMapping:
-    def __contains__(self, key) -> bool:
-        try:
-            self[key]
-        except KeyError:
-            return False
-        else:
-            return True
-
     def get(self, key, default=None) -> Object:
         try:
             return self[key]
@@ -1058,7 +1049,7 @@ class Extend_Page:
         return name
 
     def __repr__(self):
-        return repr(self.obj).replace('Dictionary', 'Page')
+        return repr(self.obj).replace('Dictionary', 'Page', 1)
 
     def _repr_mimebundle_(self, include=None, exclude=None):
         data = {}
